package org.jeecg;

import cn.com.ctop.common.module.entity.BindAccountLogin;
import cn.com.ctop.common.module.entity.CtopOauthToken;
import cn.com.ctop.common.module.entity.UserAllocation;
import cn.com.ctop.common.module.message.handle.impl.EmailSendMsgHandle;
import cn.com.ctop.common.module.service.*;
import cn.com.ctop.common.module.utils.CtopAdConstant;
import cn.com.ctop.kuaishou.modules.batch.service.IKuaiShouDailyReportTaskService;
import cn.com.ctop.kuaishou.modules.batch.service.IKuaiShouHistoryReportTaskService;
import cn.com.ctop.kuaishou.modules.graphql.service.IKuaishouWebInterfaceService;
import cn.com.ctop.kuaishou.modules.report.entity.KuaishouAgentAccount;
import cn.com.ctop.kuaishou.modules.report.mapper.KuaishouAgentAccountMapper;
import cn.com.ctop.toutiao.modules.material.service.IByteDanceAdvertiserDataService;
import cn.com.ctop.toutiao.modules.report.service.IByteDanceVideoReportDailyService;
import cn.com.ctop.toutiao.modules.report.service.IBytedanceFundDailyService;
import cn.com.ctop.toutiao.modules.report.service.IBytedanceReportService;
import cn.com.ctop.toutiao.modules.report.service.IReportService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xxl.job.core.log.XxlJobLogger;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.util.DateUtils;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.junit4.SpringRunner;

import java.math.BigDecimal;
import java.util.*;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

import static org.jeecg.common.util.DateUtils.getAnotherDay;

@RunWith(SpringRunner.class)
@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.RANDOM_PORT)
@ActiveProfiles("wps")
@Slf4j
public class SampleTest {
    @Autowired
    private ICtopOauthTokenService oauthTokenService;
    @Autowired
    private IReportService reportService;
    @Autowired
    private IByteDanceAdvertiserDataService advertiserDataService;
    @Autowired
    private IKuaiShouHistoryReportTaskService kuaiShouHistoryReportTaskService;

    @Autowired
    private ICtopOauthTokenService tokenService;

    @Test
    public void loadBytedanceCreativeData() {
        QueryWrapper<CtopOauthToken> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("media_id", 2);
        List<CtopOauthToken> list = oauthTokenService.list(queryWrapper);
        for (CtopOauthToken token : list) {
            kuaiShouHistoryReportTaskService.createTask(token.getAccountId(), token.getAccessToken(), "2020-09-20", "2020-09-20", "daily");
        }
    }

    @Autowired
    private IBindAccountLoginService bindAccountLoginService;
    @Autowired
    private IKuaishouWebInterfaceService kuaishouWebInterfaceService;

    @Test
    public void loadKuaishouCookie() {
        List<BindAccountLogin> list = bindAccountLoginService.getListByParams(CtopAdConstant.PLATFORM_TYPE_KUAISHOU_PY, 1);
        if (list != null && !list.isEmpty()) {
            int i = 0;
            for (BindAccountLogin login : list) {
                if (null == login.getCookie() || "".equals(login.getCookie().trim())) {
                    if (i > 5) {
                        break;
                    }
                    kuaishouWebInterfaceService.getkuaishouWebLoginCookie(login);
                    i++;
                }
            }
        }
    }

    static ExecutorService executorService = null;
    //线程计数器/bytedance/bytedanceMaterialReport
    static CountDownLatch countDownLatch = null;

    @Test
    public void deleteKuaishouComment() {
        Long start = System.currentTimeMillis();
        List<BindAccountLogin> loginList = bindAccountLoginService.getListByParams(CtopAdConstant.PLATFORM_TYPE_KUAISHOU_PY, 1);
        if (loginList != null && !loginList.isEmpty()) {
            executorService = Executors.newFixedThreadPool(5);
            countDownLatch = new CountDownLatch(loginList.size());
            loginList.forEach(login -> executorService.submit(() -> {
                try {
                    kuaishouWebInterfaceService.deleteAllComment(new HashMap<>(), login);
                } catch (Exception e) {
                    log.error(e.getMessage(), e);
                } finally {
                    countDownLatch.countDown();
                }
            }));
            try {
                countDownLatch.await();
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            Long end = System.currentTimeMillis();
            log.info("快手删评论所用时长：{}毫秒", end - start);
        }
    }

    @Autowired
    private IUserAllocationService allocationService;

    @Test
    public void testLoadBytedanceData() {
        List<CtopOauthToken> tokens = tokenService.selectToutiaoToken();
        executorService = Executors.newFixedThreadPool(10);
        countDownLatch = new CountDownLatch(tokens.size());
        for(int i=890;i<tokens.size();i++){
            CtopOauthToken token = tokens.get(i);
            executorService.submit(()->{
                try {
                    System.out.println(token.getAccountId());
                    for (int j = 25; j < 125; j+=10) {
                        String endDate = DateUtils.formatDate(DateUtils.addDay(new Date(), -j));
                        String startDate = DateUtils.formatDate(DateUtils.addDay(new Date(), -j-10));
                        bytedanceReportService.bytedanceMaterialReport(token, startDate, endDate);
                    }
                }catch (Exception e){
                }finally {
                    countDownLatch.countDown();
                }
            });
        }
        try {
            countDownLatch.await();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        System.out.println("任务结束");
    }

    @Test
    public void loadBytedancePlanData(){
        CtopOauthToken token = tokenService.getTokenByAccountId(100198696723L);
//        advertiserDataService.getAdvertiserPlan(token, "", null, null);
        Date getDate = DateUtils.addDay(new Date(), 0);
        reportService.getAdvertiserReport(token, getDate, getDate, CtopAdConstant.BYTEDANCE_REPORT_TYPE_HOURLY);
    }

    @Autowired
    private IBytedanceFundDailyService bytedanceFundDailyService;
    @Test
    public void loadFoudData() {
        List<CtopOauthToken> tokens = tokenService.selectToutiaoToken();
        for (CtopOauthToken token : tokens) {
            System.out.println(token.getAccountId()+"############################");
            for(int i=20;i<130;i++){
                Date date = DateUtils.addDay(new Date(),-i);
                bytedanceFundDailyService.loadFundDataByPage(token, DateUtils.formatDate(date), DateUtils.formatDate(date),1);
                System.out.println(i+"############################");
            }
        }
    }

    @Autowired
    private IKuaiShouHistoryReportTaskService reportTaskService;

    /**
     * 测试获取快手图片消耗数据任务
     */
    @Test
    public void loadKuaishouImageTask(){
        List<CtopOauthToken> tokens = tokenService.selectKuaiShouToken();
        for(int i=1;i<130;i++) {
            Date getDate = DateUtils.addDay(new Date(), -i);
            String getDateStr = DateUtils.formatDate(getDate);
            tokens.forEach(token -> reportTaskService.createTask(token.getAccountId(), token.getAccessToken(), getDateStr, getDateStr, CtopAdConstant.KUAISHOU_LOAD_JOB_TYPE_DAILY));
        }
    }

    @Autowired
    private IKuaiShouDailyReportTaskService dailyReportTaskService;
    /**
     * 测试获取快手图片消耗数据入库
     */
    @Test
    public void loadKuaishouImageTaskFile(){
        String nowDate = DateUtils.getDate("yyyy-MM-dd");
        List<CtopOauthToken> tokens = tokenService.selectKuaiShouToken();
        for(int i=1;i<15;i++){
            String statDate = getAnotherDay("yyyy-MM-dd", nowDate, -i);
            tokens.forEach(token -> dailyReportTaskService.getTaskList(token.getAccountId(), token.getAccessToken(), statDate));
        }
        //  查询快手token
    }

    @Test
    public void testLoadBytedanceImageData(){
        List<CtopOauthToken>tokens = tokenService.selectToutiaoToken();
        countDownLatch = new CountDownLatch(tokens.size());
        executorService = Executors.newFixedThreadPool(8);
        tokens.forEach(token->executorService.submit(()->{
            try {
                advertiserDataService.getMaterialList(token);
            }catch (Exception e){
            }finally {
                countDownLatch.countDown();
            }
        }));
        try {
            countDownLatch.await();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        System.out.println("素材数据获取完成");

    }
    @Autowired
    private KuaishouAgentAccountMapper kuaishouAgentAccountMapper;
    @Test
    public void loadKuaishouAgentData() throws JsonProcessingException {
//        kuaishouReportDailyAgentService.loginAgent();
//        for (int i = 0; i < 20; i++) {
//            String currentDate = DateUtils.formatDate(DateUtils.addDay(new Date(), -i));
//            kuaishouReportDailyAgentService.getReport(currentDate, DateUtils.getNowDate("yyyy-MM-dd"));
//        }
//
//        try {
//            for (int i = 1; i < 30; i++) {
//                kuaishouReportDailyAgentService.getAccount(i);
//            }
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
        String result = "{\"result\":1,\"pageInfo\":{\"currentPage\":1,\"pageSize\":100,\"totalCount\":4249},\"reviewStatusCount\":{\"totalAccount\":4249,\"readToSummit\":15,\"inReview\":0,\"reviewSuccess\":3503,\"reviewFailed\":731},\"adDspAccountList\":[{\"userId\":2125287544,\"accountId\":8132241,\"accountName\":\"User_1604025115047\",\"createTime\":1604055327504,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2125287544,\"accountId\":8132232,\"accountName\":\"User_1604025115047\",\"createTime\":1604055250505,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2125287544,\"accountId\":8132223,\"accountName\":\"User_1604025115047\",\"createTime\":1604055192252,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"旺旺记账\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2125326563,\"accountId\":8131301,\"accountName\":\"User_1604029363882\",\"createTime\":1604049907493,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"牵手\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"喜来乐（海南）电子竞技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8131228,\"accountName\":\"七七八八啾啾\",\"createTime\":1604049547107,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8131214,\"accountName\":\"七七八八啾啾\",\"createTime\":1604049488760,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8131154,\"accountName\":\"七七八八啾啾\",\"createTime\":1604049126305,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8131119,\"accountName\":\"七七八八啾啾\",\"createTime\":1604048979416,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8131099,\"accountName\":\"七七八八啾啾\",\"createTime\":1604048906991,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8131049,\"accountName\":\"七七八八啾啾\",\"createTime\":1604048695544,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8131037,\"accountName\":\"七七八八啾啾\",\"createTime\":1604048656420,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8131013,\"accountName\":\"七七八八啾啾\",\"createTime\":1604048556244,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8130996,\"accountName\":\"七七八八啾啾\",\"createTime\":1604048485221,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8130983,\"accountName\":\"七七八八啾啾\",\"createTime\":1604048430516,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1775597241,\"accountId\":8130736,\"accountName\":\"哦38236\",\"createTime\":1604047095110,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步猫\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1775597241,\"accountId\":8130682,\"accountName\":\"哦38236\",\"createTime\":1604046837594,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步猫\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1775597241,\"accountId\":8130617,\"accountName\":\"哦38236\",\"createTime\":1604046475480,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步猫\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2125324779,\"accountId\":8130518,\"accountName\":\"User_1604029169985\",\"createTime\":1604045880008,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"-\",\"firstCostDay\":\"-\",\"industry\":\"\",\"secondIndustry\":\"\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京千幻互联科技有限公司\",\"reviewStatus\":0,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":881909255,\"accountId\":8129922,\"accountName\":\"User_881909255\",\"createTime\":1604042152764,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"骏游斗地主\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"棋牌捕鱼\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"杭州骏游科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":881909255,\"accountId\":8129879,\"accountName\":\"User_881909255\",\"createTime\":1604041949313,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"骏游斗地主\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"棋牌捕鱼\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"杭州骏游科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":881909255,\"accountId\":8129856,\"accountName\":\"User_881909255\",\"createTime\":1604041791522,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"骏游斗地主\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"棋牌捕鱼\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"杭州骏游科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":881909255,\"accountId\":8129787,\"accountName\":\"User_881909255\",\"createTime\":1604041354851,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"骏游斗地主\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"棋牌捕鱼\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"杭州骏游科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":881909255,\"accountId\":8129746,\"accountName\":\"User_881909255\",\"createTime\":1604041004917,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"骏游斗地主\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"棋牌捕鱼\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"杭州骏游科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":881909255,\"accountId\":8129706,\"accountName\":\"User_881909255\",\"createTime\":1604040634142,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"骏游斗地主\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"棋牌捕鱼\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"杭州骏游科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":881909255,\"accountId\":8129676,\"accountName\":\"User_881909255\",\"createTime\":1604040423455,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"骏游斗地主\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"棋牌捕鱼\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"杭州骏游科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":881909255,\"accountId\":8129651,\"accountName\":\"User_881909255\",\"createTime\":1604040219363,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"骏游斗地主\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"棋牌捕鱼\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"杭州骏游科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":881909255,\"accountId\":8129592,\"accountName\":\"User_881909255\",\"createTime\":1604039780775,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"骏游斗地主\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"棋牌捕鱼\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"杭州骏游科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":881909255,\"accountId\":8129573,\"accountName\":\"User_881909255\",\"createTime\":1604039680061,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"骏游斗地主\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"棋牌捕鱼\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"杭州骏游科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2116553035,\"accountId\":8128511,\"accountName\":\"User_1603074687378\",\"createTime\":1604029966943,\"balance\":29876427,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":8050,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":29884477,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上消消消\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"南京网眼软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2116553035,\"accountId\":8128475,\"accountName\":\"User_1603074687378\",\"createTime\":1604029742869,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上消消消\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"南京网眼软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2116553035,\"accountId\":8128463,\"accountName\":\"User_1603074687378\",\"createTime\":1604029688168,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上消消消\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"南京网眼软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2116553035,\"accountId\":8128436,\"accountName\":\"User_1603074687378\",\"createTime\":1604029507217,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上消消消\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"南京网眼软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2116553035,\"accountId\":8128415,\"accountName\":\"User_1603074687378\",\"createTime\":1604029399325,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上消消消\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"南京网眼软件有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123911132,\"accountId\":8128176,\"accountName\":\"微店\",\"createTime\":1604027954644,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"T恤\",\"firstCostDay\":\"-\",\"industry\":\"直营电商\",\"secondIndustry\":\"服装\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京口袋购物时尚科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1957933009,\"accountId\":8127917,\"accountName\":\"Kingho\",\"createTime\":1604026349905,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"招商银行信用卡\",\"firstCostDay\":\"-\",\"industry\":\"金融服务类\",\"secondIndustry\":\"信用卡\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"招商银行股份有限公司清远分行\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2096647042,\"accountId\":8127868,\"accountName\":\"小招\",\"createTime\":1604026023996,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"招商银行信用卡\",\"firstCostDay\":\"-\",\"industry\":\"金融服务类\",\"secondIndustry\":\"信用卡\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"招商银行股份有限公司清远分行\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1311341459,\"accountId\":8127849,\"accountName\":\"Janet.537\",\"createTime\":1604025841312,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"招商银行信用卡\",\"firstCostDay\":\"-\",\"industry\":\"金融服务类\",\"secondIndustry\":\"信用卡\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"招商银行股份有限公司清远分行\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124606265,\"accountId\":8124482,\"accountName\":\"User_1603956272981\",\"createTime\":1603969317622,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"计步宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2124676103,\"accountId\":8124072,\"accountName\":\"充电得宝\",\"createTime\":1603965731499,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"充电得宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1352111759,\"accountId\":8123907,\"accountName\":\"Liang先生…\",\"createTime\":1603964663543,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"充电得宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州米财信息科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1352111759,\"accountId\":8123897,\"accountName\":\"Liang先生…\",\"createTime\":1603964562166,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"充电得宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州米财信息科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1352111759,\"accountId\":8123867,\"accountName\":\"Liang先生…\",\"createTime\":1603964350778,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"充电得宝\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州米财信息科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":623156883,\"accountId\":8123356,\"accountName\":\"（手游传奇带你飞\",\"createTime\":1603961502130,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"神途\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"角色扮演\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"河南省疯玩信息技术有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":537064166,\"accountId\":8123218,\"accountName\":\"你别管我是谁不重要\",\"createTime\":1603960674042,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"免费小说全集\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"影音娱乐\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京阅见未来网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":537064166,\"accountId\":8123168,\"accountName\":\"你别管我是谁不重要\",\"createTime\":1603960445880,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"免费小说全集\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"影音娱乐\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京阅见未来网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":537064166,\"accountId\":8123145,\"accountName\":\"你别管我是谁不重要\",\"createTime\":1603960298881,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"免费小说全集\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"影音娱乐\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京阅见未来网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8123084,\"accountName\":\"七七八八啾啾\",\"createTime\":1603959981782,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8122897,\"accountName\":\"七七八八啾啾\",\"createTime\":1603958945759,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8122828,\"accountName\":\"七七八八啾啾\",\"createTime\":1603958570690,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8122718,\"accountName\":\"七七八八啾啾\",\"createTime\":1603957957454,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8122595,\"accountName\":\"七七八八啾啾\",\"createTime\":1603957208768,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8122557,\"accountName\":\"七七八八啾啾\",\"createTime\":1603956994778,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8122498,\"accountName\":\"七七八八啾啾\",\"createTime\":1603956627975,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8122461,\"accountName\":\"七七八八啾啾\",\"createTime\":1603956386924,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8122393,\"accountName\":\"七七八八啾啾\",\"createTime\":1603956006148,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8122375,\"accountName\":\"七七八八啾啾\",\"createTime\":1603955945568,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"爱上清理球\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123911132,\"accountId\":8121452,\"accountName\":\"微店\",\"createTime\":1603950959326,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"微店\",\"firstCostDay\":\"-\",\"industry\":\"电商零售类\",\"secondIndustry\":\"综合电商\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京口袋购物时尚科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1632545895,\"accountId\":8120824,\"accountName\":\"叠仓鼠。\",\"createTime\":1603944312808,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"叠仓鼠\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"上海桥瀚科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1632545895,\"accountId\":8120816,\"accountName\":\"叠仓鼠。\",\"createTime\":1603944249495,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"叠仓鼠\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"上海桥瀚科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1632545895,\"accountId\":8120807,\"accountName\":\"叠仓鼠。\",\"createTime\":1603944184452,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"叠仓鼠\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"上海桥瀚科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1632545895,\"accountId\":8120804,\"accountName\":\"叠仓鼠。\",\"createTime\":1603944135388,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"叠仓鼠\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"上海桥瀚科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1632545895,\"accountId\":8120791,\"accountName\":\"叠仓鼠。\",\"createTime\":1603944002410,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"叠仓鼠\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"上海桥瀚科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1632545895,\"accountId\":8120789,\"accountName\":\"叠仓鼠。\",\"createTime\":1603943963352,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"叠仓鼠\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"上海桥瀚科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1632545895,\"accountId\":8120767,\"accountName\":\"叠仓鼠。\",\"createTime\":1603943840077,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"叠仓鼠\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"上海桥瀚科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1632545895,\"accountId\":8120759,\"accountName\":\"叠仓鼠。\",\"createTime\":1603943785862,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"叠仓鼠\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"上海桥瀚科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":216849348,\"accountId\":8116514,\"accountName\":\"远寻！\",\"createTime\":1603883037475,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"汽车之家极速版\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京车之家信息技术有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123781268,\"accountId\":8116213,\"accountName\":\"动感妹妹唱歌好听\",\"createTime\":1603881036639,\"balance\":18240368,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":377,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":18240745,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"动感来电秀\",\"firstCostDay\":\"2020-10-29\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123781268,\"accountId\":8116182,\"accountName\":\"动感妹妹唱歌好听\",\"createTime\":1603880879960,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"动感来电秀\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123781268,\"accountId\":8116173,\"accountName\":\"动感妹妹唱歌好听\",\"createTime\":1603880821850,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"动感来电秀\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123781268,\"accountId\":8116152,\"accountName\":\"动感妹妹唱歌好听\",\"createTime\":1603880724453,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"动感来电秀\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123781268,\"accountId\":8116140,\"accountName\":\"动感妹妹唱歌好听\",\"createTime\":1603880626766,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"动感来电秀\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"工具\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2108930614,\"accountId\":8116076,\"accountName\":\"蜜桃味的少女\uD83C\uDF51\",\"createTime\":1603880241753,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2108930614,\"accountId\":8116065,\"accountName\":\"蜜桃味的少女\uD83C\uDF51\",\"createTime\":1603880182654,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2108930614,\"accountId\":8116057,\"accountName\":\"蜜桃味的少女\uD83C\uDF51\",\"createTime\":1603880142160,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2108930614,\"accountId\":8116037,\"accountName\":\"蜜桃味的少女\uD83C\uDF51\",\"createTime\":1603880065790,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2108930614,\"accountId\":8116028,\"accountName\":\"蜜桃味的少女\uD83C\uDF51\",\"createTime\":1603880018711,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"猜歌达人\",\"firstCostDay\":\"-\",\"industry\":\"游戏类\",\"secondIndustry\":\"休闲益智\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州小迈网络科技有限公司\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123670412,\"accountId\":8115819,\"accountName\":\"User_1603850991793\",\"createTime\":1603878847622,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京易卡互动信息技术有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123670412,\"accountId\":8115779,\"accountName\":\"User_1603850991793\",\"createTime\":1603878652946,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京易卡互动信息技术有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123670412,\"accountId\":8115774,\"accountName\":\"User_1603850991793\",\"createTime\":1603878620036,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京易卡互动信息技术有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123670412,\"accountId\":8115757,\"accountName\":\"User_1603850991793\",\"createTime\":1603878473649,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京易卡互动信息技术有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123670412,\"accountId\":8115731,\"accountName\":\"User_1603850991793\",\"createTime\":1603878359736,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"易车\",\"firstCostDay\":\"-\",\"industry\":\"交通类\",\"secondIndustry\":\"汽车资讯与服务平台\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"北京易卡互动信息技术有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1912290458,\"accountId\":8115667,\"accountName\":\"焦糖\",\"createTime\":1603877933074,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"焦糖\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州随手玩网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1912290458,\"accountId\":8115660,\"accountName\":\"焦糖\",\"createTime\":1603877875405,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"焦糖\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州随手玩网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1912290458,\"accountId\":8115624,\"accountName\":\"焦糖\",\"createTime\":1603877666317,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"焦糖\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州随手玩网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1912290458,\"accountId\":8115612,\"accountName\":\"焦糖\",\"createTime\":1603877588231,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"焦糖\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广州随手玩网络科技有限公司\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1912290458,\"accountId\":8115590,\"accountName\":\"焦糖\",\"createTime\":1603877481943,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"焦糖\",\"firstCostDay\":\"-\",\"industry\":\"资讯类\",\"secondIndustry\":\"婚恋/交友\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"广·\u009Eé\u009A\u008Fæ\u0089\u008Bç\u008E©ç½\u0091ç»\u009Cç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1912290458,\"accountId\":8115565,\"accountName\":\"ç\u0084¦ç³\u0096\",\"createTime\":1603877339397,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"ç\u0084¦ç³\u0096\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å©\u009Aæ\u0081\u008B/äº¤å\u008F\u008B\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å¹¿å·\u009Eé\u009A\u008Fæ\u0089\u008Bç\u008E©ç½\u0091ç»\u009Cç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1912290458,\"accountId\":8115555,\"accountName\":\"ç\u0084¦ç³\u0096\",\"createTime\":1603877293560,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"ç\u0084¦ç³\u0096\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å©\u009Aæ\u0081\u008B/äº¤å\u008F\u008B\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å¹¿å·\u009Eé\u009A\u008Fæ\u0089\u008Bç\u008E©ç½\u0091ç»\u009Cç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1912290458,\"accountId\":8115508,\"accountName\":\"ç\u0084¦ç³\u0096\",\"createTime\":1603876999442,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"ç\u0084¦ç³\u0096\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å©\u009Aæ\u0081\u008B/äº¤å\u008F\u008B\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å¹¿å·\u009Eé\u009A\u008Fæ\u0089\u008Bç\u008E©ç½\u0091ç»\u009Cç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1912290458,\"accountId\":8115443,\"accountName\":\"ç\u0084¦ç³\u0096\",\"createTime\":1603876540456,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"ç\u0084¦ç³\u0096\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å©\u009Aæ\u0081\u008B/äº¤å\u008F\u008B\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å¹¿å·\u009Eé\u009A\u008Fæ\u0089\u008Bç\u008E©ç½\u0091ç»\u009Cç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1912290458,\"accountId\":8115315,\"accountName\":\"ç\u0084¦ç³\u0096\",\"createTime\":1603875760021,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"ç\u0084¦ç³\u0096\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å©\u009Aæ\u0081\u008B/äº¤å\u008F\u008B\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å¹¿å·\u009Eé\u009A\u008Fæ\u0089\u008Bç\u008E©ç½\u0091ç»\u009Cç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":3,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123707266,\"accountId\":8115018,\"accountName\":\"ä¸\u0083ä¸\u0083å\u0085«å\u0085«å\u0095¾å\u0095¾\",\"createTime\":1603873755267,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"ç\u0088±ä¸\u008Aæ¸\u0085ç\u0090\u0086ç\u0090\u0083\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å·¥å\u0085·\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å¹¿å·\u009Eå°\u008Fè¿\u0088ç½\u0091ç»\u009Cç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":1887324412,\"accountId\":8114743,\"accountName\":\"æµ·è±\u009Aå®¶\",\"createTime\":1603872428441,\"balance\":19999593,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":407,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":20000000,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"æµ·è±\u009Aå®¶\",\"firstCostDay\":\"-\",\"industry\":\"ç\u0094µå\u0095\u0086é\u009B¶å\u0094®ç±»\",\"secondIndustry\":\"è·¨å¢\u0083\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å\u008C\u0097äº¬å\u0087¯è°±ä¹\u0090ç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123800548,\"accountId\":8114685,\"accountName\":\"User_1603866467861\",\"createTime\":1603872122324,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"çº¢æ\u009F\u009Aå\u0085\u008Dè´¹å°\u008Fè¯´\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å½±é\u009F³å¨±ä¹\u0090\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å\u008C\u0097äº¬æ\u0097 é\u0099\u0090å\u0085\u0089å\u009Cºç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123800548,\"accountId\":8114663,\"accountName\":\"User_1603866467861\",\"createTime\":1603872010568,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"çº¢æ\u009F\u009Aå\u0085\u008Dè´¹å°\u008Fè¯´\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å½±é\u009F³å¨±ä¹\u0090\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å\u008C\u0097äº¬æ\u0097 é\u0099\u0090å\u0085\u0089å\u009Cºç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123800548,\"accountId\":8114650,\"accountName\":\"User_1603866467861\",\"createTime\":1603871944481,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"çº¢æ\u009F\u009Aå\u0085\u008Dè´¹å°\u008Fè¯´\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å½±é\u009F³å¨±ä¹\u0090\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å\u008C\u0097äº¬æ\u0097 é\u0099\u0090å\u0085\u0089å\u009Cºç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123800548,\"accountId\":8114626,\"accountName\":\"User_1603866467861\",\"createTime\":1603871807865,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"çº¢æ\u009F\u009Aå\u0085\u008Dè´¹å°\u008Fè¯´\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å½±é\u009F³å¨±ä¹\u0090\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å\u008C\u0097äº¬æ\u0097 é\u0099\u0090å\u0085\u0089å\u009Cºç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123800548,\"accountId\":8114618,\"accountName\":\"User_1603866467861\",\"createTime\":1603871763066,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"çº¢æ\u009F\u009Aå\u0085\u008Dè´¹å°\u008Fè¯´\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å½±é\u009F³å¨±ä¹\u0090\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å\u008C\u0097äº¬æ\u0097 é\u0099\u0090å\u0085\u0089å\u009Cºç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123800548,\"accountId\":8114593,\"accountName\":\"User_1603866467861\",\"createTime\":1603871645156,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"çº¢æ\u009F\u009Aå\u0085\u008Dè´¹å°\u008Fè¯´\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å½±é\u009F³å¨±ä¹\u0090\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å\u008C\u0097äº¬æ\u0097 é\u0099\u0090å\u0085\u0089å\u009Cºç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]},{\"userId\":2123800548,\"accountId\":8114580,\"accountName\":\"User_1603866467861\",\"createTime\":1603871557073,\"balance\":0,\"creditBalance\":0,\"extendedBalance\":0,\"rebate\":0,\"preRebate\":0,\"contractRebate\":0,\"directRebate\":0,\"totalBalance\":0,\"loLimit\":0,\"singleOut\":0,\"autoOut\":false,\"balanceWarn\":false,\"productName\":\"çº¢æ\u009F\u009Aå\u0085\u008Dè´¹å°\u008Fè¯´\",\"firstCostDay\":\"-\",\"industry\":\"èµ\u0084è®¯ç±»\",\"secondIndustry\":\"å½±é\u009F³å¨±ä¹\u0090\",\"kuaibiBalance\":0,\"pushBalance\":0,\"recharged\":false,\"corporationName\":\"å\u008C\u0097äº¬æ\u0097 é\u0099\u0090å\u0085\u0089å\u009Cºç§\u0091æ\u008A\u0080æ\u009C\u0089é\u0099\u0090å\u0085¬å\u008F¸\",\"reviewStatus\":2,\"frozenStatus\":0,\"transferAccountStatus\":true,\"reviewDetail\":[]}],\"host-name\":\"ad-rs1833.idczw.hb1.kwaidc.com\"}";
        ObjectMapper mapper = new ObjectMapper();
        mapper.disable(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES);
        JsonNode resultNode = mapper.readTree(result);
        Integer code = resultNode.get("result").intValue();
        if (code == 1) {
            Iterator<JsonNode> iterator1 = resultNode.get("adDspAccountList").elements();
            int i = 0;
            List<KuaishouAgentAccount> accountList = new ArrayList<>();
            while (iterator1.hasNext()) {
                JsonNode dataNode = iterator1.next();
                KuaishouAgentAccount agentAccount = mapper.readValue(dataNode.toString(), KuaishouAgentAccount.class);
                agentAccount.setBalance(agentAccount.getBalance().divide(new BigDecimal(1000)));
                agentAccount.setContractRebate(agentAccount.getContractRebate().divide(new BigDecimal(1000)));
                agentAccount.setCreditBalance(agentAccount.getCreditBalance().divide(new BigDecimal(1000)));
                agentAccount.setDirectRebate(agentAccount.getDirectRebate().divide(new BigDecimal(1000)));
                agentAccount.setExtendedBalance(agentAccount.getExtendedBalance().divide(new BigDecimal(1000)));
                agentAccount.setKuaibiBalance(agentAccount.getKuaibiBalance().divide(new BigDecimal(1000)));
                agentAccount.setPreRebate(agentAccount.getPreRebate().divide(new BigDecimal(1000)));
                agentAccount.setPushBalance(agentAccount.getPushBalance().divide(new BigDecimal(1000)));
                agentAccount.setRebate(agentAccount.getRebate().divide(new BigDecimal(1000)));
                agentAccount.setTotalBalance(agentAccount.getTotalBalance().divide(new BigDecimal(1000)));
                accountList.add(agentAccount);
            }
            if (!accountList.isEmpty()) {
                kuaishouAgentAccountMapper.replaceBatch(accountList);
            }
        }
    }




    @Test
    public void loadAccountData() {
//        List<UserAllocation> allocations = allocationService.getByParams(776L,null,0);
//        for (UserAllocation allocation:allocations) {
            CtopOauthToken token = tokenService.getTokenByAccountId(93238965516L);
            for(int i=92;i<100;i++){
                Date getDate = DateUtils.addDay(new Date(),-i);
                reportService.getAdvertiserReport(token, getDate, getDate, CtopAdConstant.BYTEDANCE_REPORT_TYPE_DAILY);
            }
//        }
    }

    @Autowired
    IUReportExportService uReportExportService;
    @Autowired
    EmailSendMsgHandle emailSendMsgHandle;
    @Autowired
    IUReportService uReportService;

    @Test
    public void loadBytedanceData(){
        List<CtopOauthToken> tokens = tokenService.selectToutiaoToken();
        for (int i=0;i<tokens.size();i++) {
            for(int j=0;j<4;j++){
                String getDate = DateUtils.formatDate(DateUtils.addDay(new Date(), -j));
                bytedanceReportService.bytedanceVideoMaterialReport(tokens.get(i), getDate, getDate);
            }
        }
    }

    @Autowired
    private IBytedanceReportService bytedanceReportService;

    @Autowired
    private IByteDanceVideoReportDailyService videoReportDailyService;
    @Test
    public void loadMatData(){
        List<UserAllocation> allocations = allocationService.getByParams(289L,null,0);
        countDownLatch = new CountDownLatch(allocations.size());
        executorService = Executors.newFixedThreadPool(2);
        allocations.forEach(allocation -> {
            executorService.submit(new Runnable() {
                @Override
                public void run() {
                    try {
                        CtopOauthToken token = tokenService.getTokenByAccountId(allocation.getAccountId());
                        //获取全量视频素材数据
                        advertiserDataService.getMaterialList(token);
                    } catch (Exception e) {
                        e.printStackTrace();
                    } finally {
                        countDownLatch.countDown();
                    }
                }
            });
        });
        try {
            countDownLatch.await();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        XxlJobLogger.log("物料数据同步完成");
    }
}
