package cn.com.ctop.alarm.modules.service.impl;

import cn.com.ctop.alarm.modules.entity.AlarmEventMetric;
import cn.com.ctop.alarm.modules.entity.AlarmEventRule;
import cn.com.ctop.alarm.modules.mapper.AlarmEventMetricMapper;
import cn.com.ctop.alarm.modules.mapper.AlarmEventRuleMapper;
import cn.com.ctop.alarm.modules.service.IAlarmEventRuleService;
import cn.com.ctop.common.module.utils.Check;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 预警事件规则表
 * 完成Condition
 * CURRENT_TODAY_DATA
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2020-10-29
 */
@Service
public class AlarmEventRuleServiceImpl extends ServiceImpl<AlarmEventRuleMapper, AlarmEventRule> implements IAlarmEventRuleService {

    @Autowired
    private AlarmEventRuleMapper alarmEventRuleMapper;

    @Autowired
    private AlarmEventMetricMapper alarmEventMetricMapper;

    @Override
    public void addAlarmEventRule(JSONObject obj) {
        AlarmEventRule rule = new AlarmEventRule();
        rule.setAccountId(obj.getLong("accountId"));
        rule.setUnitId(obj.getLong("unitId"));
        rule.setEventRuleName(obj.getString("eventRuleName"));
        rule.setEventRuleLevel(obj.getString("eventRuleLevel"));
        rule.setCheckFrequency(obj.getString("checkFrequency"));
        rule.setProcessMethod(obj.getString("processMethod"));
        rule.setEventRuleStatus(obj.getString("eventRuleStatus"));
        alarmEventRuleMapper.insert(rule);
        JSONArray metrics = obj.getJSONArray("alarmEventMetric");
        for (int i = 0; i < metrics.size(); i++) {
            JSONObject mo = metrics.getJSONObject(i);
            AlarmEventMetric metric = new AlarmEventMetric();
            metric.setEventRuleId(rule.getEventRuleId());
            metric.setMetricValueCode(mo.getString("metricValueCode"));
            metric.setJudgeType(mo.getString("judgeType"));
            metric.setJudgeMethod(mo.getString("judgeMethod"));
            metric.setThreshold(mo.getString("threshold"));
            metric.setMinThreshold(mo.getString("minThreshold"));
            metric.setDataRange(mo.getString("dataRange"));
            alarmEventMetricMapper.insert(metric);
        }
    }

    @Override
    public void editAlarmEventRule(JSONObject obj) {
        AlarmEventRule rule = new AlarmEventRule();
        Long accountId = obj.getLong("accountId");
        if (!Check.isNull(accountId)) {
            rule.setAccountId(accountId);
        }
        Long unitId = obj.getLong("unitId");
        if (!Check.isNull(unitId)) {
            rule.setUnitId(unitId);
        }
        String eventRuleName = obj.getString("eventRuleName");
        if (!Check.isNull(eventRuleName)) {
            rule.setEventRuleName(eventRuleName);
        }
        String eventRuleLevel = obj.getString("eventRuleLevel");
        if (!Check.isNull(eventRuleLevel)) {
            rule.setEventRuleLevel(eventRuleLevel);
        }
        String checkFrequency = obj.getString("checkFrequency");
        if (!Check.isNull(checkFrequency)) {
            rule.setCheckFrequency(checkFrequency);
        }
        String processMethod = obj.getString("processMethod");
        if (!Check.isNull(processMethod)) {
            rule.setProcessMethod(processMethod);

        }
        String eventRuleStatus = obj.getString("eventRuleStatus");
        if (!Check.isNull(eventRuleStatus)) {
            rule.setEventRuleStatus(eventRuleStatus);
        }
        QueryWrapper<AlarmEventRule> ruleWrapper = new QueryWrapper<>();
        ruleWrapper.eq("event_rule_id", obj.getLong("eventRuleId"));
        alarmEventRuleMapper.update(rule, ruleWrapper);
        JSONArray metrics = obj.getJSONArray("alarmEventMetric");
        for (int i = 0; i < metrics.size(); i++) {
            JSONObject mo = metrics.getJSONObject(i);
            AlarmEventMetric metric = new AlarmEventMetric();
            Long eventRuleId = rule.getEventRuleId();
            if (!Check.isNull(eventRuleId)) {
                metric.setEventRuleId(eventRuleId);
            }
            String metricValueCode = mo.getString("metricValueCode");
            if (!Check.isNull(metricValueCode)) {
                metric.setMetricValueCode(metricValueCode);
            }
            String judgeType = mo.getString("judgeType");
            if (!Check.isNull(judgeType)) {
                metric.setJudgeType(judgeType);
            }
            String judgeMethod = mo.getString("judgeMethod");
            if (!Check.isNull(judgeMethod)) {
                metric.setJudgeMethod(judgeMethod);
            }
            String threshold = mo.getString("threshold");
            if (!Check.isNull(threshold)) {
                metric.setThreshold(threshold);
            }
            String minThreshold = mo.getString("minThreshold");
            if (!Check.isNull(minThreshold)) {
                metric.setMinThreshold(minThreshold);
            }
            String dataRange = mo.getString("dataRange");
            if (!Check.isNull(dataRange)) {
                metric.setDataRange(dataRange);
            }
            QueryWrapper<AlarmEventMetric> metricWrapper = new QueryWrapper<>();
            metricWrapper.eq("event_metric_id", mo.getLong("eventMetricId"));
            metricWrapper.eq("event_rule_id", obj.getLong("eventRuleId"));
            alarmEventMetricMapper.update(metric, metricWrapper);
        }
    }

    @Override
    public AlarmEventRule selectById(String id) {
        AlarmEventRule alarmEventRule = alarmEventRuleMapper.selectById(id);
        List<AlarmEventMetric> alarmEventMetricList = alarmEventMetricMapper.selectByEventRuleId(id);
        return alarmEventRule.setAlarmEventMetrics(alarmEventMetricList);

    }
}
